==> apache-servicecomb-java-chassis-distribution-1.3.11-src.zip: apache-servicecomb-java-chassis-distribution-1.3.11-src/foundations/foundation-ssl/src/test/java/org/apache/servicecomb/foundation/ssl/TestTrustAllManager.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.foundation.ssl;

import java.net.Socket;
import java.security.cert.X509Certificate;

import javax.net.ssl.SSLEngine;

import org.junit.Assert;
import org.junit.Test;

public class TestTrustAllManager {
  @Test
  public void testTrustAllManager() throws Exception {
    TrustAllManager manager = new TrustAllManager();
    manager.checkClientTrusted((X509Certificate[]) null, (String) null);
    manager.checkServerTrusted((X509Certificate[]) null, (String) null);

    manager.checkClientTrusted((X509Certificate[]) null,
        (String) null,
        (Socket) null);
    manager.checkClientTrusted((X509Certificate[]) null,
        (String) null,
        (SSLEngine) null);

    manager.checkServerTrusted((X509Certificate[]) null,
        (String) null,
        (Socket) null);
    manager.checkServerTrusted((X509Certificate[]) null,
        (String) null,
        (SSLEngine) null);
    Assert.assertEquals(manager.getAcceptedIssuers() == null, true);
  }
}

==> apache-servicecomb-java-chassis-distribution-2.8.29-src.zip: apache-servicecomb-java-chassis-distribution-2.8.29-src/foundations/foundation-ssl/src/test/java/org/apache/servicecomb/foundation/ssl/TestTrustAllManager.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.foundation.ssl;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

import java.net.Socket;
import java.security.cert.X509Certificate;

import javax.net.ssl.SSLEngine;

public class TestTrustAllManager {
  @Test
  public void testTrustAllManager() throws Exception {
    TrustAllManager manager = new TrustAllManager();
    manager.checkClientTrusted((X509Certificate[]) null, (String) null);
    manager.checkServerTrusted((X509Certificate[]) null, (String) null);

    manager.checkClientTrusted((X509Certificate[]) null,
        (String) null,
        (Socket) null);
    manager.checkClientTrusted((X509Certificate[]) null,
        (String) null,
        (SSLEngine) null);

    manager.checkServerTrusted((X509Certificate[]) null,
        (String) null,
        (Socket) null);
    manager.checkServerTrusted((X509Certificate[]) null,
        (String) null,
        (SSLEngine) null);
    Assertions.assertNull(manager.getAcceptedIssuers());
  }
}
